<?php
$translations = array(
	'General_Locale' => 'ko_KR.UTF-8',
	'General_TranslatorName' => 'Jong-In Kim',
	'General_TranslatorEmail' => 'soulofpure@hotmail.com',
	'General_EnglishLanguageName' => 'Korean',
	'General_OriginalLanguageName' => '한국어',
	'General_HelloUser' => '안녕하세요, %s 님!',
	'General_OpenSourceWebAnalytics' => '오픈 소스 웹 분석기',
	'General_API' => 'API',
	'General_Widgets' => '위젯',
	'General_Settings' => '설정',
	'General_GiveUsYourFeedback' => '피드백을 주세요!',
	'General_Unknown' => '알수없음',
	'General_Required' => '%s 필요함',
	'General_Error' => '에러',
	'General_Warning' => '경고',
	'General_BackToHomepage' => 'Piwik 홈페이지로 돌아가기',
	'General_Yes' => '예',
	'General_No' => '아니오',
	'General_Delete' => '삭제',
	'General_Edit' => '편집',
	'General_Ok' => 'OK',
	'General_Close' => '닫기',
	'General_Logout' => '로그아웃',
	'General_Done' => '끝',
	'General_LoadingData' => '데이터 로딩중...',
	'General_Loading_js' => '로딩중...',
	'General_Next' => '다음',
	'General_Previous' => '이전',
	'General_Search' => '검색',
	'General_Others' => '다른 것들',
	'General_Table' => '테이블',
	'General_Piechart' => '파이차트',
	'General_TagCloud' => '태그 클라우드',
	'General_VBarGraph' => '수직 막대 그래프',
	'General_Refresh' => '페이지 새로고침',
	'General_Visitors' => '방문자 수',
	'General_Export' => '내보내기',
	'General_ErrorRequest' => '요청중에 문제가 발생했습니다. 다시 시도해보세요.',
	'General_ColumnNbUniqVisitors' => '고유 방문자 수',
	'General_ColumnNbVisits' => '방문 수',
	'General_ColumnNbActions' => '활동 수',
	'General_ColumnMaxActions' => '한번 방문에 최대 활동 수',
	'General_ColumnSumVisitLength' => '방문자의 방문 최대 시간(초 단위)',
	'General_ColumnLabel' => '라벨',
	'General_ColumnActionsPerVisit' => '방문 당 활동 수',
	'General_ColumnAvgTimeOnSite' => '웹사이트 평균 시간',
	'General_ColumnBounceRate' => '반송률',
	'General_ColumnPageviews' => '페이지뷰',
	'General_ColumnUniquePageviews' => '고유 페이지뷰',
	'General_ColumnValuePerVisit' => '방문 당 값',
	'General_ColumnVisitsWithConversions' => '전환을 통한 방문 수',
	'General_Save' => '저장',
	'General_Website' => '웹사이트',
	'General_NoDataForGraph' => '이 그래프를 위한 데이터가 없습니다.',
	'General_NoDataForTagCloud' => '이 태그 클라우드를 위한 데이터가 없습니다.',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %1$s 이 사용 가능합니다. %2$s 지금 업데이트하세요!%3$s (보기: %4$s 변경%5$s).',
	'General_BackToPiwik' => 'Piwik으로 돌아가기',
	'General_ShortMonth_1' => '1월',
	'General_ShortMonth_2' => '2월',
	'General_ShortMonth_3' => '3월',
	'General_ShortMonth_4' => '4월',
	'General_ShortMonth_5' => '5월',
	'General_ShortMonth_6' => '6월',
	'General_ShortMonth_7' => '7월',
	'General_ShortMonth_8' => '8월',
	'General_ShortMonth_9' => '9월',
	'General_ShortMonth_10' => '10월',
	'General_ShortMonth_11' => '11월',
	'General_ShortMonth_12' => '12월',
	'General_LongMonth_1' => '1월',
	'General_LongMonth_2' => '2월',
	'General_LongMonth_3' => '3월',
	'General_LongMonth_4' => '4월',
	'General_LongMonth_5' => '5월',
	'General_LongMonth_6' => '6월',
	'General_LongMonth_7' => '7월',
	'General_LongMonth_8' => '8월',
	'General_LongMonth_9' => '9월',
	'General_LongMonth_10' => '10월',
	'General_LongMonth_11' => '11월',
	'General_LongMonth_12' => '12월',
	'General_ShortDay_1' => '월',
	'General_ShortDay_2' => '화',
	'General_ShortDay_3' => '수',
	'General_ShortDay_4' => '목',
	'General_ShortDay_5' => '금',
	'General_ShortDay_6' => '토',
	'General_ShortDay_7' => '일',
	'General_LongDay_1' => '월요일',
	'General_LongDay_2' => '화요일',
	'General_LongDay_3' => '수요일',
	'General_LongDay_4' => '목요일',
	'General_LongDay_5' => '금요일',
	'General_LongDay_6' => '토요일',
	'General_LongDay_7' => '일요일',
	'Actions_Actions' => '활동',
	'Actions_SubmenuPages' => '페이지',
	'Actions_SubmenuOutlinks' => '아웃링크',
	'Actions_SubmenuDownloads' => '다운로드',
	'Actions_ColumnClicks' => '조회수',
	'Actions_ColumnUniqueClicks' => '고유 조회수',
	'Actions_ColumnDownloads' => '다운로드 수',
	'Actions_ColumnUniqueDownloads' => '고유 다운로드 수',
	'Actions_ColumnPageName' => '페이지명',
	'Actions_ColumnClickedURL' => '조회한 URL',
	'Actions_ColumnDownloadURL' => '다운로드 URL',
	'API_LoadedAPIs' => '성공적으로 %s API를 불러옴',
	'CoreHome_CategoryNoData' => '이 카테고리 안에 데이터가 없습니다. "모든 집단 포함"을 시도해보세요.',
	'CoreHome_ShowJSCode' => '삽입할 자바스크립트 코드 보기',
	'CoreHome_PageOf_js' => '%1$s : %2$s',
	'CoreHome_PeriodDay' => '일간',
	'CoreHome_PeriodWeek' => '주간',
	'CoreHome_PeriodMonth' => '월간',
	'CoreHome_PeriodYear' => '년간',
	'CoreHome_PeriodDays' => '일간',
	'CoreHome_PeriodWeeks' => '주간',
	'CoreHome_PeriodMonths' => '월간',
	'CoreHome_PeriodYears' => '년간',
	'CoreHome_DaySu_js' => '일',
	'CoreHome_DayMo_js' => '월',
	'CoreHome_DayTu_js' => '화',
	'CoreHome_DayWe_js' => '수',
	'CoreHome_DayTh_js' => '목',
	'CoreHome_DayFr_js' => '금',
	'CoreHome_DaySa_js' => '토',
	'CoreHome_ShortDay_1_js' => '일',
	'CoreHome_ShortDay_2_js' => '월',
	'CoreHome_ShortDay_3_js' => '화',
	'CoreHome_ShortDay_4_js' => '수',
	'CoreHome_ShortDay_5_js' => '목',
	'CoreHome_ShortDay_6_js' => '금',
	'CoreHome_ShortDay_7_js' => '토',
	'CoreHome_LongDay_1_js' => '일',
	'CoreHome_LongDay_2_js' => '월',
	'CoreHome_LongDay_3_js' => '화',
	'CoreHome_LongDay_4_js' => '수',
	'CoreHome_LongDay_5_js' => '목',
	'CoreHome_LongDay_6_js' => '금',
	'CoreHome_LongDay_7_js' => '토',
	'CoreHome_ShortMonth_1_js' => '1월',
	'CoreHome_ShortMonth_2_js' => '2월',
	'CoreHome_ShortMonth_3_js' => '3월',
	'CoreHome_ShortMonth_4_js' => '4월',
	'CoreHome_ShortMonth_5_js' => '5월',
	'CoreHome_ShortMonth_6_js' => '6월',
	'CoreHome_ShortMonth_7_js' => '7월',
	'CoreHome_ShortMonth_8_js' => '8월',
	'CoreHome_ShortMonth_9_js' => '9월',
	'CoreHome_ShortMonth_10_js' => '10월',
	'CoreHome_ShortMonth_11_js' => '11월',
	'CoreHome_ShortMonth_12_js' => '12월',
	'CoreHome_MonthJanuary_js' => '1월',
	'CoreHome_MonthFebruary_js' => '2월',
	'CoreHome_MonthMarch_js' => '3월',
	'CoreHome_MonthApril_js' => '4월',
	'CoreHome_MonthMay_js' => '5월',
	'CoreHome_MonthJune_js' => '6월',
	'CoreHome_MonthJuly_js' => '7월',
	'CoreHome_MonthAugust_js' => '8월',
	'CoreHome_MonthSeptember_js' => '9월',
	'CoreHome_MonthOctober_js' => '10월',
	'CoreHome_MonthNovember_js' => '11월',
	'CoreHome_MonthDecember_js' => '12월',
	'CorePluginsAdmin_Plugins' => '플러그인',
	'CorePluginsAdmin_PluginsManagement' => '플러그인 관리',
	'CorePluginsAdmin_MainDescription' => '플러그인 확장과 Piwik의 기능성 확장페이지입니다. 플러그인이 한번 설치되면 이곳에서 활성화하거나 비활성화하실 수 있습니다.',
	'CorePluginsAdmin_Plugin' => '플러그인',
	'CorePluginsAdmin_Version' => '버전',
	'CorePluginsAdmin_Status' => '상태',
	'CorePluginsAdmin_Action' => '동작',
	'CorePluginsAdmin_PluginHomepage' => '플러그인 홈페이지',
	'CorePluginsAdmin_Activated' => '활성화됨',
	'CorePluginsAdmin_Active' => '활성',
	'CorePluginsAdmin_Inactive' => '비활성',
	'CorePluginsAdmin_Deactivate' => '비활성화',
	'CorePluginsAdmin_Activate' => '활성화',
	'CorePluginsAdmin_MenuPlugins' => '플러그인',
	'CoreUpdater_UpdateTitle' => 'Piwik › 업데이트',
	'CoreUpdater_DatabaseUpgradeRequired' => '데이터베이스 업그레이드 필요함',
	'CoreUpdater_YourDatabaseIsOutOfDate' => 'Piwik 데이터베이스가 오래되었으니 계속하기 이전에 먼저 업그레이드가 되어야 합니다.',
	'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'Piwik 데이터베이스가 %1$s 버전에서 %2$s 새 버전으로 업그레이드됩니다.',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => '다음의 플러그인들이 업데이트됩니다: %s.',
	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => '데이터베이스 업그레이드 진행은 시간이 걸릴 수 있으므로 기다려주세요.',
	'CoreUpdater_UpgradePiwik' => 'Piwik 업그레이드',
	'CoreUpdater_HelpMessageContent' => '업데이트 도중에 발생하는 공통적인 에러가 설명되어 있는 %1$s Piwik FAQ %2$s 를 확인하세요. %3$s 시스템 관리자에게 물어보세요 - 에러는 서버나 MySQL 설정과 관련되어 있는 경우가 많아 도움을 줄 수도 있습니다.',
	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => '업데이트 과정중에 치명적인 에러 발생:',
	'CoreUpdater_HelpMessageIntroductionWhenError' => '위와 같은 경우는 코어 에러 메세지입니다. 원인을 설명할 수 있으나 도움이 필요하다면:',
	'CoreUpdater_HelpMessageIntroductionWhenWarning' => '업데이트는 성공적으로 완료되었습니다. 하지만 진행중에 문제가 있었습니다. 자세한 사항은 위의 설명을 읽어주세요. 더 많은 도움은:',
	'CoreUpdater_UpgradeComplete' => '업그레이드 완료!',
	'CoreUpdater_WarningMessages' => '경고 메세지:',
	'CoreUpdater_ErrorDuringPluginsUpdates' => '플러그인 업데이트 도중 에러 발생:',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => '다음의 플러그인을 자동으로 비활성화하였습니다: %s',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik 이 성공적으로 업데이트되었습니다!',
	'CoreUpdater_ContinueToPiwik' => 'Piwik 계속 하기',
	'CoreUpdater_UpdateAutomatically' => '자동 업데이트',
	'CoreUpdater_ThereIsNewVersionAvailableForUpdate' => 'Piwik의 새 버전으로 업데이트 할 수 있습니다.',
	'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => '%s 버전으로 자동 업데이트하거나 수동적으로 패키지를 받아서 업데이트 할 수 있습니다:',
	'CoreUpdater_DownloadX' => '다운로드 %s',
	'CoreUpdater_UpdateHasBeenCancelledExplanation' => 'Piwik 원클릭 업데이트가 취소되었습니다. 만약 위의 에러 메세지를 고칠 수 없다면, 수동으로 Piwik을 업데이트하는 것을 권장합니다. %1$s 시작하기 위해 %2$s업데이트 문서%3$s 를 확인하세요!',
	'CoreUpdater_VerifyingUnpackedFiles' => '압축이 풀린 파일 확인중',
	'CoreUpdater_CreatingBackupOfConfigurationFile' => '%s 안의 설정 파일 백업 생성중',
	'CoreUpdater_InstallingTheLatestVersion' => '최근 버전 설치중',
	'CoreUpdater_PiwikUpdatedSuccessfully' => 'Piwik 업데이트가 성공적으로 완료되었습니다!',
	'CoreUpdater_EmptyDatabaseError' => '데이터베이스 %s 는 비어있습니다. Piwik 설정 파일을 편집하거나 제거해야 합니다.',
	'Dashboard_Dashboard' => '대시보드',
	'Dashboard_DeleteWidgetConfirm' => '대시보드에서 이 위젯을 삭제하시겠습니까?',
	'Dashboard_SelectWidget' => '대시보드에 추가할 위젯 선택',
	'Dashboard_AddPreviewedWidget_js' => '대시보드에 미리보기된 위젯 추가',
	'Dashboard_WidgetPreview_js' => '위젯 미리보기',
	'Dashboard_Close_js' => '닫기',
	'Dashboard_TitleWidgetInDashboard_js' => '대시보드에 이미 위젯이 있습니다',
	'Dashboard_TitleClickToAdd_js' => '클릭해서 대시보드에 추가',
	'Dashboard_LoadingWidget_js' => '위젯 로딩중, 잠시만 기다리세요...',
	'Dashboard_WidgetNotFound_js' => '위젯을 찾지 못함',
	'DBStats_DatabaseUsage' => '데이터베이스 사용량',
	'DBStats_MainDescription' => 'Piwik은 모든 웹 분석 데이터를 MySQL 데이터베이스에 저장하고 있습니다. 현재, Piwik 테이블은 %s 를 사용하고 있습니다.',
	'DBStats_Table' => '테이블',
	'DBStats_DataSize' => '데이터 용량',
	'DBStats_IndexSize' => '인덱스 용량',
	'DBStats_TotalSize' => '전체 용량',
	'Goals_ColumnConversions' => '전환수',
	'Goals_ColumnRevenue' => '수익',
	'Installation_Installation' => '설치',
	'Installation_InstallationStatus' => '설치 상태',
	'Installation_PercentDone' => '%s %% 완료',
	'Installation_NoConfigFound' => 'Piwik 설정 파일을 찾을 수 없으며 당신은 Piwik 페이지로 접근을 계속 시도하고 있습니다.<br /><b>  » <a href=\'index.php\'>지금 Piwik을 설치하세요.</a></b><br /><small>만약 Piwik을 이전에 설치한 적이 있고 DB에 테이블이 좀 있다면 걱정하지마세요, 같은 테이블을 재사용할 수 있고 현재 데이터를 보존할 수 있습니다!</small>',
	'Installation_JsTag' => '자바스크립트 태그',
	'Installation_Congratulations' => '축하합니다',
	'Installation_CongratulationsHelp' => '<p>축하합니다! Piwik 설치가 완료되었습니다.</p><p>페이지에 자바스크립트 코드가 입력되있는지 확인하시고 첫 방문객을 기다리세요!</p>',
	'Installation_ContinueToPiwik' => 'Piwik 계속 하기',
	'Installation_SetupWebsite' => '웹사이트 설정',
	'Installation_SetupWebsiteError' => '웹사이트 추가중에 에러가 있었습니다',
	'Installation_SuperUserLogin' => '슈퍼 사용자 로그인',
	'Installation_Password' => '비밀번호',
	'Installation_PasswordRepeat' => '비밀번호 (반복)',
	'Installation_Email' => '이메일',
	'Installation_SecurityNewsletter' => 'Piwik의 주요 업그레이드 그리고 보안 경고를 이메일로 받기',
	'Installation_CommunityNewsletter' => '커뮤니티 업데이트를 이메일로 받기 (새로운 플러그인,새로운 기능 등등)',
	'Installation_PasswordDoNotMatch' => '비밀번호가 맞지 않습니다',
	'Installation_Requirements' => 'Piwik 요구 사항',
	'Installation_Optional' => '옵션',
	'Installation_Legend' => '범례',
	'Installation_SystemCheck' => '시스템 체크',
	'Installation_SystemCheckPhp' => 'PHP 버전',
	'Installation_SystemCheckExtensions' => '필수 확장',
	'Installation_SystemCheckSplHelp' => '스탠다드 PHP 라이브러리가 활성화된 상태로 PHP를 설정하고 리빌딩해야 합니다. (기본).',
	'Installation_SystemCheckZlibHelp' => 'zlib 지원 활성화가 된 상태로 PHP를 설정하고 리빌빙해야 합니다.',
	'Installation_SystemCheckWriteDirs' => '쓰기 접근 가능 디렉토리',
	'Installation_SystemCheckWriteDirsHelp' => '리눅스 시스템에서 이 에러를 고치기 위해서, 다음 명령어를 입력해보세요.',
	'Installation_SystemCheckMemoryLimit' => '메모리 제한',
	'Installation_SystemCheckMemoryLimitHelp' => '높은 트래픽의 웹사이트에서는 압축 진행중에 현재 허용된 것보다 더 높은 메모리를 필요로 할 수 있습니다. 만약 필요하다면 php.ini 파일에서 memory_limit을 변경하세요.',
	'Installation_SystemCheckGD' => 'GD > 2.x (그래픽)',
	'Installation_SystemCheckGDHelp' => '스파크라인(소규모 그래프)은 작동하지 않습니다.',
	'Installation_SystemCheckFunctions' => '필수 기능',
	'Installation_SystemCheckTimeLimitHelp' => '높은 트래픽의 웹사이트에서는 압축 진행중에 현재 허용된 것보다 더 많은 시간을 필요로 할 수 있습니다. 만약 필요하다면 php.ini 파일에서 max_execution_time을 변경하세요..',
	'Installation_SystemCheckMailHelp' => 'mail() 없이 피드백과 잊어버린 비밀번호 메세지는 보내지지 않습니다.',
	'Installation_SystemCheckError' => '에러 발생 - 진행 전에 수정이 필요함',
	'Installation_SystemCheckWarning' => 'Piwik 은 정상적으로 작동하지만 몇몇의 기능이 작동하지 않을 수 있습니다.',
	'Installation_Tables' => '테이블 생성',
	'Installation_TablesWithSameNamesFound' => '몇몇의 테이블: %1$s / 데이터베이스: %2$s 가 Piwik이 생성하려고 하는 테이블 이름과 같습니다.',
	'Installation_TablesFound' => '데이터베이스에서 다음의 테이블을 찾았습니다',
	'Installation_TablesWarningHelp' => '존재하는 데이터베이스 테이블을 재사용하거나 모든 존재하는 데이터를 삭제하고 클린 설치를 할 지 선택하세요.',
	'Installation_TablesReuse' => '존재하는 테이블을 재사용',
	'Installation_TablesDelete' => '감지된 테이블 삭제',
	'Installation_TablesDeletedSuccess' => '존재하는 Piwik 테이블을 성공적으로 삭제했습니다',
	'Installation_TablesCreatedSuccess' => '테이블 생성을 성공적으로 마쳤습니다!',
	'Installation_DatabaseCreatedSuccess' => '데이터베이스 %s 를 성공적으로 생성했습니다!',
	'Installation_GoBackAndDefinePrefix' => '돌아가서 Piwik 테이블을 위해 Prefix를 정의합니다',
	'Installation_ConfirmDeleteExistingTables' => '테이블 %s 을(를) 데이터베이스로부터 삭제하기를 원합니까? 경고: 이 테이블의 데이터는 복구되지 않습니다!',
	'Installation_Welcome' => '환영합니다!',
	'Installation_WelcomeHelp' => '<p>Piwik 은 오픈 소스 웹 분석 소프트웨어로써 쉽고 원하는 정보를 당신의 방문자들로부터 얻을 수 있게 해줍니다.</p><p>이 과정은 %s 의 쉬운 단계로 나뉘어 있고 5분 정도만 소요됩니다.</p>',
	'Installation_ErrorInvalidState' => '에러: 설치 과정의 단계를 뛰어넘으려고 하는 것 같습니다, 또는 쿠키가 비활성화거나, 또는 Piwik 설정 파일이 이미 생성되었습니다. %1$s쿠키가 활성화되어 있는지 확인하시고%2$s 설치 첫페이지로 %3$s 돌아가세요 %4$s.',
	'Login_LoginPasswordNotCorrect' => '사용자명 & 비밀번호가 맞지 않습니다',
	'Login_Password' => '비밀번호',
	'Login_LoginOrEmail' => '아이디 또는 이메일',
	'Login_LogIn' => '로그인',
	'Login_Logout' => '로그아웃',
	'Login_LostYourPassword' => '비밀번호를 잊으셨습니까?',
	'Login_InvalidUsernameEmail' => '잘못된 사용자명 그리고/또는 이메일 주소',
	'Login_ContactAdmin' => '가능한 이유: 호스트가 메일 기능을 비활성화했을 수 있습니다. <br />당신의 Piwik 관리자에게 연락해보세요.',
	'Provider_WidgetProviders' => '공급자',
	'Provider_ColumnProvider' => '공급자',
	'Provider_SubmenuLocationsProvider' => '위치&공급자',
	'Referers_Referers' => '리퍼러',
	'Referers_SearchEngines' => '검색엔진',
	'Referers_Keywords' => '키워드',
	'Referers_DirectEntry' => '직접 입력',
	'Referers_Websites' => '웹사이트',
	'Referers_Campaigns' => '캠페인',
	'Referers_Evolution' => '기간동안 진행 과정',
	'Referers_Type' => '리퍼러 타입',
	'Referers_ColumnRefererType' => '리퍼러 타입',
	'Referers_ColumnSearchEngine' => '검색엔진',
	'Referers_ColumnWebsite' => '웹사이트',
	'Referers_ColumnWebsitePage' => '웹사이트 페이지',
	'Referers_ColumnKeyword' => '키워드',
	'Referers_ColumnCampaign' => '캠페인',
	'Referers_DetailsByRefererType' => '리퍼러 타입에 의한 세부사항',
	'Referers_TypeDirectEntries' => '%s (직접 입력)',
	'Referers_TypeSearchEngines' => '%s (검색엔진을 통해서)',
	'Referers_TypeWebsites' => '%s (웹사이트를 통해서)',
	'Referers_TypeCampaigns' => '%s (캠페인을 통해서)',
	'Referers_Distinct' => '리퍼러 타입에 의한 고유 리퍼러',
	'Referers_DistinctSearchEngines' => '고유 검색엔진',
	'Referers_DistinctKeywords' => '고유 키워드',
	'Referers_DistinctCampaigns' => '고유 캠페인',
	'Referers_DistinctWebsites' => '고유 웹사이트',
	'Referers_SubmenuSearchEngines' => '검색엔진&키워드',
	'Referers_SubmenuWebsites' => '웹사이트',
	'Referers_SubmenuCampaigns' => '캠페인',
	'Referers_WidgetKeywords' => '키워드 목록',
	'Referers_WidgetCampaigns' => '캠페인 목록',
	'Referers_WidgetExternalWebsites' => '외부 웹사이트 목록',
	'Referers_WidgetSearchEngines' => '인기 검색엔진',
	'Referers_WidgetOverview' => '개요',
	'SitesManager_Sites' => '웹사이트',
	'SitesManager_WebsitesManagement' => '웹사이트 관리',
	'SitesManager_MainDescription' => '웹 분석 리포트는 웹사이트가 필요합니다! 추가,업데이트,웹사이트 삭제, 그리고 페이지에 삽입한 자바스크립트를 봅니다.',
	'SitesManager_JsTrackingTag' => '자바스크립트 트래킹 태그',
	'SitesManager_JsTrackingTagHelp' => '모든 페이지를 포함한 자바스크립트 트래킹 태그입니다.',
	'SitesManager_ShowTrackingTag' => '트래킹 태그 보기',
	'SitesManager_NoWebsites' => '관리할 웹사이트를 가지고 있지 않습니다.',
	'SitesManager_AddSite' => '새 사이트 추가',
	'SitesManager_Urls' => 'URL',
	'SitesManager_MenuSites' => '웹사이트',
	'SitesManager_DeleteConfirm_js' => '%s 웹사이트를 삭제하시겠습니까?',
	'SitesManager_ExceptionDeleteSite' => '이 웹사이트만 등록되있기에 이 웹사이트를 삭제할 수 없습니다. 새 웹사이트를 먼저 추가하시고 이 웹사이트를 삭제하세요.',
	'SitesManager_ExceptionNoUrl' => '최소한 하나의 웹사이트 URL을 넣어주셔야 합니다.',
	'SitesManager_ExceptionEmptyName' => '웹사이트명은 빈칸으로 둘 수 없습니다.',
	'SitesManager_ExceptionInvalidUrl' => 'URL \'%s\' 은(는) 유효한 URL이 아닙니다.',
	'TranslationsAdmin_MenuTranslations' => '번역',
	'TranslationsAdmin_MenuLanguages' => '언어',
	'TranslationsAdmin_LanguageCode' => '언어 코드',
	'TranslationsAdmin_Plugin' => '플러그인',
	'TranslationsAdmin_Definition' => '정의',
	'TranslationsAdmin_DefaultString' => '기본 문자 (영어)',
	'TranslationsAdmin_TranslationString' => '번역 문자 (현재 언어: %s)',
	'TranslationsAdmin_Translations' => '번역',
	'TranslationsAdmin_FixPermissions' => '파일시스템 권한을 수정하세요',
	'TranslationsAdmin_AddLanguage' => '언어 추가',
	'TranslationsAdmin_Export' => '언어 내보내기',
	'TranslationsAdmin_Import' => '언어 가져오기',
	'UserCountry_Country' => '나라',
	'UserCountry_Continent' => '대륙',
	'UserCountry_DistinctCountries' => '%s 개의 나라',
	'UserCountry_SubmenuLocations' => '위치',
	'UserCountry_country_ac' => '어센션 섬',
	'UserCountry_country_ad' => '안도라',
	'UserCountry_country_ae' => '아랍에미리트',
	'UserCountry_country_af' => '아프가니스탄',
	'UserCountry_country_ag' => '앤티가 바부다',
	'UserCountry_country_ai' => '앵귈라',
	'UserCountry_country_al' => '알바니아',
	'UserCountry_country_am' => '아르메니아',
	'UserCountry_country_an' => '네덜란드령 안틸레스',
	'UserCountry_country_ao' => '앙골라',
	'UserCountry_country_aq' => '남극',
	'UserCountry_country_ar' => '아르헨티나',
	'UserCountry_country_as' => '아메리칸 사모아',
	'UserCountry_country_at' => '오스트리아',
	'UserCountry_country_au' => '호주',
	'UserCountry_country_aw' => '아루바',
	'UserCountry_country_ax' => '올란드제도',
	'UserCountry_country_az' => '아제르바이잔',
	'UserCountry_country_ba' => '보스니아 헤르체코비나',
	'UserCountry_country_bb' => '바바도스',
	'UserCountry_country_bd' => '방글라데시',
	'UserCountry_country_be' => '벨기에',
	'UserCountry_country_bf' => '부르키나파소',
	'UserCountry_country_bg' => '불가리아',
	'UserCountry_country_bh' => '바레인',
	'UserCountry_country_bi' => '부룬디',
	'UserCountry_country_bj' => '베넹',
	'UserCountry_country_bl' => '세인트 바데레미',
	'UserCountry_country_bm' => '버뮤다',
	'UserCountry_country_bn' => '브루노',
	'UserCountry_country_bo' => '볼리비아',
	'UserCountry_country_br' => '브라질',
	'UserCountry_country_bs' => '바하마스',
	'UserCountry_country_bt' => '부탄',
	'UserCountry_country_bu' => '버마',
	'UserCountry_country_bv' => '부베 섬',
	'UserCountry_country_bw' => '보츠와나',
	'UserCountry_country_by' => '벨라루스',
	'UserCountry_country_bz' => '벨리즈',
	'UserCountry_country_ca' => '캐나다',
	'UserCountry_country_cc' => '코코스 아일랜드',
	'UserCountry_country_cd' => '콩고 민주 공화국',
	'UserCountry_country_cf' => '중앙 아프리카',
	'UserCountry_country_cg' => '콩고',
	'UserCountry_country_ch' => '스위스',
	'UserCountry_country_ci' => '코트디부아르',
	'UserCountry_country_ck' => '쿡 아일랜드',
	'UserCountry_country_cl' => '칠레',
	'UserCountry_country_cm' => '카메룬',
	'UserCountry_country_cn' => '중국',
	'UserCountry_country_co' => '콜롬비아',
	'UserCountry_country_cp' => '클리퍼턴 섬',
	'UserCountry_country_cr' => '코스타리카',
	'UserCountry_country_cs' => '세르비아 몬테네그로',
	'UserCountry_country_cu' => '쿠바',
	'UserCountry_country_cv' => '카보베르데',
	'UserCountry_country_cx' => '크리스마스 아일랜드',
	'UserCountry_country_cy' => '키프로스',
	'UserCountry_country_cz' => '체코',
	'UserCountry_country_de' => '독일',
	'UserCountry_country_dg' => '디에고 가르시아',
	'UserCountry_country_dj' => '지부티',
	'UserCountry_country_dk' => '덴마크',
	'UserCountry_country_dm' => '도미니카',
	'UserCountry_country_do' => '도미니카 공화국',
	'UserCountry_country_dz' => '알제리아',
	'UserCountry_country_ea' => '세우타 멜릴라',
	'UserCountry_country_ec' => '에콰도르',
	'UserCountry_country_ee' => '에스토니아',
	'UserCountry_country_eg' => '이집트',
	'UserCountry_country_eh' => '서부 사하라',
	'UserCountry_country_er' => '에리트레아',
	'UserCountry_country_es' => '스페인',
	'UserCountry_country_et' => '에티오피아',
	'UserCountry_country_eu' => '유럽 연합',
	'UserCountry_country_fi' => '핀란드',
	'UserCountry_country_fj' => '피지',
	'UserCountry_country_fk' => '포클랜드 제도(영국령)',
	'UserCountry_country_fm' => '미크로네시아 연방',
	'UserCountry_country_fo' => '페로 제도',
	'UserCountry_country_fr' => '프랑스',
	'UserCountry_country_fx' => '프랑스, 메트로폴리탄',
	'UserCountry_country_ga' => '가봉',
	'UserCountry_country_gb' => '대영제국',
	'UserCountry_country_gd' => '그레나다',
	'UserCountry_country_ge' => '그루지아',
	'UserCountry_country_gf' => '가이아나 프랑스령',
	'UserCountry_country_gg' => '건지 섬',
	'UserCountry_country_gh' => '가나',
	'UserCountry_country_gi' => '지브롤터',
	'UserCountry_country_gl' => '그린랜드',
	'UserCountry_country_gm' => '감비아',
	'UserCountry_country_gn' => '기니',
	'UserCountry_country_gp' => '귀아들루프',
	'UserCountry_country_gq' => '적도 기니',
	'UserCountry_country_gr' => '그리스',
	'UserCountry_country_gs' => '사우스조지아 사우스샌드위치 제도',
	'UserCountry_country_gt' => '과테말라',
	'UserCountry_country_gu' => '괌',
	'UserCountry_country_gw' => '기니비사우',
	'UserCountry_country_gy' => '가이아나',
	'UserCountry_country_hk' => '홍콩',
	'UserCountry_country_hm' => '허드맥도날드 제도',
	'UserCountry_country_hn' => '온두라스',
	'UserCountry_country_hr' => '크로아티아',
	'UserCountry_country_ht' => '아이티',
	'UserCountry_country_hu' => '헝가리',
	'UserCountry_country_ic' => '카나리아 제도',
	'UserCountry_country_id' => '인도네시아',
	'UserCountry_country_ie' => '아일랜드',
	'UserCountry_country_il' => '이스라엘',
	'UserCountry_country_im' => '맨 아일랜드',
	'UserCountry_country_in' => '인도',
	'UserCountry_country_io' => '영국령 인도양 식민지',
	'UserCountry_country_iq' => '이라크',
	'UserCountry_country_ir' => '이란 회교 공화국',
	'UserCountry_country_is' => '아이슬란드',
	'UserCountry_country_it' => '이탈리아',
	'UserCountry_country_je' => '저지 섬',
	'UserCountry_country_jm' => '자메이카',
	'UserCountry_country_jo' => '요르단',
	'UserCountry_country_jp' => '일본',
	'UserCountry_country_ke' => '케냐',
	'UserCountry_country_kg' => '키르키즈스탄',
	'UserCountry_country_kh' => '캄보디아',
	'UserCountry_country_ki' => '키리바시',
	'UserCountry_country_km' => '코모로스',
	'UserCountry_country_kn' => '세인트키츠 네비스',
	'UserCountry_country_kp' => '북한',
	'UserCountry_country_kr' => '대한민국',
	'UserCountry_country_kw' => '쿠웨이트',
	'UserCountry_country_ky' => '케이맨 제도',
	'UserCountry_country_kz' => '카자흐스탄',
	'UserCountry_country_la' => '라오스',
	'UserCountry_country_lb' => '레바논',
	'UserCountry_country_lc' => '세인트루시아',
	'UserCountry_country_li' => '리히텐슈타인',
	'UserCountry_country_lk' => '스리랑카',
	'UserCountry_country_lr' => '라이베리아',
	'UserCountry_country_ls' => '레소토',
	'UserCountry_country_lt' => '리투아니아',
	'UserCountry_country_lu' => '룩셈버그',
	'UserCountry_country_lv' => '라티비아',
	'UserCountry_country_ly' => '리비아',
	'UserCountry_country_ma' => '모로코',
	'UserCountry_country_mc' => '모나코',
	'UserCountry_country_md' => '몰도바',
	'UserCountry_country_me' => '몬테그로',
	'UserCountry_country_mf' => '세인트 마틴',
	'UserCountry_country_mg' => '마다가스카',
	'UserCountry_country_mh' => '마쉘 제도',
	'UserCountry_country_mk' => '마세도니아',
	'UserCountry_country_ml' => '말리',
	'UserCountry_country_mm' => '미얀마',
	'UserCountry_country_mn' => '몽골',
	'UserCountry_country_mo' => '마카우',
	'UserCountry_country_mp' => '북마리아나 제도',
	'UserCountry_country_mq' => '마르티니크',
	'UserCountry_country_mr' => '모리타니',
	'UserCountry_country_ms' => '몬트세랫',
	'UserCountry_country_mt' => '몰타',
	'UserCountry_country_mu' => '모리셔스',
	'UserCountry_country_mv' => '몰디브',
	'UserCountry_country_mw' => '말라위',
	'UserCountry_country_mx' => '멕시코',
	'UserCountry_country_my' => '말레이시아',
	'UserCountry_country_mz' => '모잠비크',
	'UserCountry_country_na' => '나미비아',
	'UserCountry_country_nc' => '뉴 칼레도니아',
	'UserCountry_country_ne' => '니제르',
	'UserCountry_country_nf' => '노퍽 섬',
	'UserCountry_country_ng' => '나이지리아',
	'UserCountry_country_ni' => '니카라과',
	'UserCountry_country_nl' => '네덜란드',
	'UserCountry_country_no' => '노르웨이',
	'UserCountry_country_np' => '네팔',
	'UserCountry_country_nr' => '나우루',
	'UserCountry_country_nt' => '중성대',
	'UserCountry_country_nu' => '니우에',
	'UserCountry_country_nz' => '뉴질랜드',
	'UserCountry_country_om' => '오만',
	'UserCountry_country_pa' => '파나마',
	'UserCountry_country_pe' => '페루',
	'UserCountry_country_pf' => '프랑스령 폴리네시아',
	'UserCountry_country_pg' => '파푸아뉴기니',
	'UserCountry_country_ph' => '필리핀',
	'UserCountry_country_pk' => '파키스탄',
	'UserCountry_country_pl' => '폴란드',
	'UserCountry_country_pm' => '생피에르 미클롱',
	'UserCountry_country_pn' => '핏케언',
	'UserCountry_country_pr' => '푸에트리코',
	'UserCountry_country_ps' => '팔레스타인',
	'UserCountry_country_pt' => '포르투칼',
	'UserCountry_country_pw' => '팔라우',
	'UserCountry_country_py' => '파라과이',
	'UserCountry_country_qa' => '카타르',
	'UserCountry_country_re' => '레위니옹 섬',
	'UserCountry_country_ro' => '루마니아',
	'UserCountry_country_rs' => '세르비아',
	'UserCountry_country_ru' => '러시아',
	'UserCountry_country_rw' => '르완다',
	'UserCountry_country_sa' => '사우디 아라비아',
	'UserCountry_country_sb' => '솔로몬 아일랜드',
	'UserCountry_country_sc' => '세이셸',
	'UserCountry_country_sd' => '수단',
	'UserCountry_country_se' => '스웨덴',
	'UserCountry_country_sf' => '핀란드',
	'UserCountry_country_sg' => '싱가포르',
	'UserCountry_country_sh' => '세인트 헬레나',
	'UserCountry_country_si' => '슬로베니아',
	'UserCountry_country_sj' => '스발바드 제도',
	'UserCountry_country_sk' => '슬로바키아',
	'UserCountry_country_sl' => '시에라리온',
	'UserCountry_country_sm' => '산마리노',
	'UserCountry_country_sn' => '세네갈',
	'UserCountry_country_so' => '소말리아',
	'UserCountry_country_sr' => '수리남',
	'UserCountry_country_st' => '상투메프린시페',
	'UserCountry_country_su' => '구소련',
	'UserCountry_country_sv' => '엘살바도르',
	'UserCountry_country_sy' => '시리아',
	'UserCountry_country_sz' => '스와질란드',
	'UserCountry_country_ta' => '트리스탄 다 쿠나',
	'UserCountry_country_tc' => '터크스 케이커스 제도',
	'UserCountry_country_td' => '차드',
	'UserCountry_country_tf' => '프랑스령 남부',
	'UserCountry_country_tg' => '토고',
	'UserCountry_country_th' => '태국',
	'UserCountry_country_tj' => '타지키스탄',
	'UserCountry_country_tk' => '토켈라우',
	'UserCountry_country_tl' => '동티모르',
	'UserCountry_country_tm' => '투르크메니스탄',
	'UserCountry_country_tn' => '튀니지아',
	'UserCountry_country_to' => '통가',
	'UserCountry_country_tp' => '동티모르',
	'UserCountry_country_tr' => '터키',
	'UserCountry_country_tt' => '트리니다드 토바고',
	'UserCountry_country_tv' => '투발루',
	'UserCountry_country_tw' => '대만',
	'UserCountry_country_tz' => '탄자니아',
	'UserCountry_country_ua' => '우크레이나',
	'UserCountry_country_ug' => '우간다',
	'UserCountry_country_uk' => '영국',
	'UserCountry_country_um' => '미국령 군소 제도',
	'UserCountry_country_us' => '미국',
	'UserCountry_country_uy' => '우루과이',
	'UserCountry_country_uz' => '우즈베키스탄',
	'UserCountry_country_va' => '바티칸 시티',
	'UserCountry_country_vc' => '세인트빈센트 그레나딘',
	'UserCountry_country_ve' => '베네수엘라',
	'UserCountry_country_vg' => '영국령 버진 아일랜드',
	'UserCountry_country_vi' => '미국령 버진 아일랜드',
	'UserCountry_country_vn' => '베트남',
	'UserCountry_country_vu' => '바누아투',
	'UserCountry_country_wf' => '왈리스 피튀나',
	'UserCountry_country_ws' => '사모아',
	'UserCountry_country_ye' => '예멘',
	'UserCountry_country_yt' => '마요트',
	'UserCountry_country_yu' => '유고슬라비아',
	'UserCountry_country_za' => '남아프리카',
	'UserCountry_country_zm' => '잠비아',
	'UserCountry_country_zr' => '자이르',
	'UserCountry_country_zw' => '짐바브웨',
	'UserCountry_continent_eur' => '유럽',
	'UserCountry_continent_afr' => '아프리카',
	'UserCountry_continent_asi' => '아시아',
	'UserCountry_continent_amn' => '북미',
	'UserCountry_continent_ams' => '중남미',
	'UserCountry_continent_oce' => '오세아니아',
	'UserSettings_VisitorSettings' => '방문자 설정',
	'UserSettings_BrowserFamilies' => '브라우저 타입',
	'UserSettings_Browsers' => '브라우저',
	'UserSettings_Plugins' => '플러그인',
	'UserSettings_Configurations' => '구성',
	'UserSettings_OperatingSystems' => '운영체제',
	'UserSettings_Resolutions' => '해상도',
	'UserSettings_WideScreen' => '와이드 스크린',
	'UserSettings_ColumnBrowserFamily' => '브라우저 타입',
	'UserSettings_ColumnBrowser' => '브라우저',
	'UserSettings_ColumnPlugin' => '플러그인',
	'UserSettings_ColumnConfiguration' => '구성',
	'UserSettings_ColumnOperatingSystem' => '운영체제',
	'UserSettings_ColumnResolution' => '해상도',
	'UserSettings_ColumnTypeOfScreen' => '스크린 타입',
	'UserSettings_WidgetResolutions' => '스크린 해상도',
	'UserSettings_WidgetBrowsers' => '방문자 브라우저',
	'UserSettings_WidgetPlugins' => '플러그인 목록',
	'UserSettings_WidgetWidescreen' => '보통 / 와이드 스크린',
	'UserSettings_WidgetBrowserFamilies' => '브라우저 타입',
	'UserSettings_WidgetOperatingSystems' => '운영체제',
	'UserSettings_WidgetGlobalVisitors' => '글로벌 방문자 구성',
	'UserSettings_SubmenuSettings' => '설정',
	'UsersManager_UsersManagement' => '사용자 관리',
	'UsersManager_UsersManagementMainDescription' => '새로운 사용자를 생성하거나 또는 존재하는 사용자를 업데이트할 수 있습니다. 그리고 위에서 그들의 권한을 설정할 수 있습니다.',
	'UsersManager_ManageAccess' => '관리 접근',
	'UsersManager_MainDescription' => '어떤 사용자가 어떤 Piwik 접근을 할 지 결정할 수 있습니다. 모든 웹사이트의 권한을 한번에 설정할 수 있습니다.',
	'UsersManager_Sites' => '웹사이트',
	'UsersManager_AllWebsites' => '모든 웹사이트',
	'UsersManager_ApplyToAllWebsites' => '모든 웹사이트에 적용',
	'UsersManager_User' => '사용자',
	'UsersManager_PrivNone' => '접근할 수 없음',
	'UsersManager_PrivView' => '보기',
	'UsersManager_PrivAdmin' => '관리자',
	'UsersManager_ChangeAllConfirm' => '모든 웹사이트에 대한 \'%s\' 권한을 변경하시겠습니까?',
	'UsersManager_Password' => '비밀번호',
	'UsersManager_Email' => '이메일',
	'UsersManager_Alias' => '별명',
	'UsersManager_Edit' => '편집',
	'UsersManager_AddUser' => '새 사용자 추가',
	'UsersManager_MenuUsers' => '사용자',
	'UsersManager_DeleteConfirm_js' => '사용자 %s 님을 삭제하시겠습니까?',
	'UsersManager_ExceptionLoginExists' => '\'%s\' 님은 이미 존재합니다.',
	'UsersManager_ExceptionEmailExists' => '\'%s\' 의 이메일을 가진 사용자는 이미 존재합니다.',
	'UsersManager_ExceptionInvalidLoginFormat' => '아이디는 %1$s 에서 %2$s 사이의 글자 수여야 하고 오직 문자,숫자, 또는 \'_\' 나 \'-\' 또는 \'.\'만 포함해야 합니다.',
	'UsersManager_ExceptionInvalidEmail' => '이메일이 유효한 형식이 아닙니다.',
	'UsersManager_ExceptionDeleteDoesNotExist' => '사용자 \'%s\' 님은 존재하지 않아서 삭제가 불가능합니다.',
	'UsersManager_ExceptionAdminAnonymous' => '\'관리자\' 권한을 \'익명\' 사용자에게 줄 수 없습니다.',
	'UsersManager_ExceptionEditAnonymous' => '익명 사용자는 편집이나 삭제를 할 수 없습니다. Piwik에서 아직 로그인하지 않은 사용자를 골라낼 때 사용하기 때문입니다. 예를 들어, \'보기\' 접근을 \'익명\' 사용자에게 주어서 당신의 상태를 공개할 수 있습니다.',
	'UsersManager_ExceptionSuperUser' => '요청한 사용자는 슈퍼 사용자이며 API를 통해 쿼리,편집,삭제할 수 없습니다. Piwik 설정 파일에서 슈퍼 사용자를 수동으로 편집할 수 있습니다.',
	'UsersManager_ExceptionUserDoesNotExist' => '사용자 \'%s\' 님은 존재하지 않습니다.',
	'UsersManager_ExceptionAccessValues' => '파라미터 접근은 다음과 같은 값중에 하나여야 합니다 : [ %s ]',
	'VisitFrequency_Evolution' => '기간동안 진행 과정',
	'VisitFrequency_ColumnReturningVisits' => '돌아온 방문 수',
	'VisitFrequency_ColumnActionsByReturningVisits' => '돌아온 방문의 활동 수',
	'VisitFrequency_ColumnBounceRateForReturningVisits' => '돌아온 방문의 반송률',
	'VisitFrequency_ReturnVisits' => '%s 돌아온 방문 수',
	'VisitFrequency_ReturnActions' => '%s 돌아온 방문의 활동 수',
	'VisitFrequency_ReturnBounceRate' => '%s 바로 떠난 방문 비율 (한 페이지만 보고 떠난 방문자)',
	'VisitFrequency_WidgetOverview' => '프리퀸시 개요',
	'VisitFrequency_WidgetGraphReturning' => '돌아온 방문 수 그래프',
	'VisitFrequency_SubmenuFrequency' => '프리퀸시',
	'VisitorInterest_VisitsPerDuration' => '방문시 소요 시간',
	'VisitorInterest_VisitsPerNbOfPages' => '방문시 읽은 페이지 수',
	'VisitorInterest_ColumnVisitDuration' => '방문 시간',
	'VisitorInterest_ColumnPagesPerVisit' => '방문시 읽은 페이지 수',
	'VisitorInterest_WidgetLengths' => '방문의 길이',
	'VisitorInterest_WidgetPages' => '방문시 읽은 페이지 수',
	'VisitorInterest_PlusXMin' => '%s분',
	'VisitorInterest_OnePage' => '1 개의 페이지',
	'VisitorInterest_NPages' => '%s 개의 페이지',
	'VisitsSummary_NbVisits' => '%s 방문 수',
	'VisitsSummary_NbUniqueVisitors' => '%s 고유 방문자 수',
	'VisitsSummary_MaxNbActions' => '%s 한번 방문의 최대 활동 수',
	'VisitsSummary_NbVisitsBounced' => '%s 바로 떠난 방문 비율 (한 페이지만 보고 떠난 방문자)',
	'VisitsSummary_GenerateTime' => '페이지 생성에 %s 초 걸림',
	'VisitsSummary_GenerateQueries' => '%s 쿼리 실행됨',
	'VisitsSummary_WidgetLastVisits' => '최근 방문 그래프',
	'VisitsSummary_WidgetVisits' => '방문자 개요',
	'VisitsSummary_WidgetLastVisitors' => '최근 고유 방문자 그래프',
	'VisitsSummary_WidgetOverviewGraph' => '개요 그래프',
	'VisitsSummary_SubmenuOverview' => '개요',
	'VisitTime_LocalTime' => '현지 시간 기준 방문 수',
	'VisitTime_ServerTime' => '서버 시간 기준 방문 수',
	'VisitTime_ColumnServerTime' => '서버 시간',
	'VisitTime_ColumnLocalTime' => '현지 시간',
	'VisitTime_WidgetLocalTime' => '현지 시간 기준 방문 수',
	'VisitTime_WidgetServerTime' => '서버 시간 기준 방문 수',
	'VisitTime_SubmenuTimes' => '시간',
	'VisitTime_NHour' => '%s시',
);
